-- LuaRocks configuration

rocks_trees = {
   { name = "user", root = home .. "/.luarocks" };
   { name = "system", root = "/clangarm64" };
}
variables = {
   LUA_DIR = "/clangarm64";
   LUA_INCDIR = "/clangarm64/include/lua5.1";
   LUA_BINDIR = "/clangarm64/bin";
   LUA_VERSION = "5.1";
   LUA = "/clangarm64/bin/lua.exe";
}
